@@ -1,6 +1,3 @@
-from time import time
-
-from crawlMp import start_time
 from crawlMp.results import Results
 
 
@@ -11,7 +8,7 @@ def print_summary(results: Results = None) -> None:
     :return: None
     """
     if results is not None:
-        print(f"Crawled in: {round(time() - start_time, 2)} s")
+        print(f"Crawled in: {round(results.done_time - results.start_time, 2)} s")
         print(f"Number of hits: {len(results.hits)}")
         print(f"Number of followed links: {len(results.links_followed)}")
         print(f"Number of skipped links: {len(results.links_skipped)}")
@@ -27,4 +24,4 @@ def print_list(results: Results = None) -> None:
     :return: None
     """
     if len(results.hits) > 0:
-        print(*[result for result in results.hits], sep="\n")
+        print(*[result[0] for result in results.hits], sep="\n")
